export interface Point {
    x: number;
    y: number;
}
export declare class LazyPoint implements Point {
    x: number;
    y: number;
    constructor(x: number, y: number);
    /**
     * Update the x and y values
     */
    update(point: Point): LazyPoint;
    /**
     * Move the point to another position using an angle and distance
     */
    moveByAngle(angle: number, distance: number, friction?: number): LazyPoint;
    /**
     * Check if this point is the same as another point
     */
    equalsTo(point: Point): boolean;
    /**
     * Get the difference for x and y axis to another point
     */
    getDifferenceTo(point: Point): LazyPoint;
    /**
     * Calculate distance to another point
     */
    getDistanceTo(point: Point): number;
    /**
     * Calculate the angle to another point
     */
    getAngleTo(point: Point): number;
    /**
     * Return a simple object with x and y properties
     */
    toObject(): Point;
}
